@@ -10,13 +10,13 @@ from pangeamt_tea.project.project import (
 )
 from pangeamt_tea.project.workflow.workflow import Workflow
 from pangeamt_tea.project.workflow.workflow import WorkflowAlreadyExists
-
-# from pangeamt_tea.project.train.train import train as model_trainer
 from pangeamt_nlp.processor.processor_factory import ProcessorFactory
 from pangeamt_nlp.processor.base.normalizer_base import NormalizerBase
 from pangeamt_nlp.translation_model.translation_model_factory import (
     TranslationModelFactory,
 )
+from pangeamt_tea.project.workflow.stage.train_stage import TrainStage
+from pangeamt_tea.project.workflow.stage.eval_stage import EvalStage
 
 
 @click.group(invoke_without_command=True)
@@ -370,12 +370,21 @@ async def prepare(ctx: Context, num_workers: int = 1):
     type=click.INT,
     help="The GPU where the model will be trained",
 )
+@click.option(
+    "--continue_train",
+    "-c",
+    help="Name of the model from which to resume training",
+)
 @click.pass_context
-async def train(ctx: Context, gpu: int):
+async def train(ctx: Context, gpu: int, continue_train: str):
     try:
         workflow = Workflow.load(ctx.obj["project"])
-        await workflow.run_stage("train", gpu)
-        click.echo("---> Done")
+        if continue_train is None:
+            await workflow.run_stage("train", gpu)
+            click.echo("---> Done")
+        else:
+            train_stage = TrainStage(workflow)
+            await train_stage.run(gpu, continue_train)
     except Exception as e:
         click.echo(f"Error: {e}")
 
@@ -394,11 +403,24 @@ async def train(ctx: Context, gpu: int):
     type=click.INT,
     help="The steps of the desired model to evaluate",
 )
+@click.option(
+    "--src", help="Source file for evaluation",
+)
+@click.option(
+    "--ref", help="Reference file"
+)
 @click.pass_context
-async def eval(ctx: Context, gpu: int, step: int):
+async def eval(ctx: Context, gpu: int, step: int, src: str, ref: str):
     try:
         workflow = Workflow.load(ctx.obj["project"])
-        await workflow.run_stage("eval", gpu, step)
+        if src is not None:
+            if ref is not None:
+                eval_stage = EvalStage(workflow)
+                await eval_stage.eval_files(gpu, step, src, ref)
+            else:
+                print("Reference path missing")
+        else:
+            await workflow.run_stage("eval", gpu, step)
         click.echo("---> Done")
     except Exception as e:
         click.echo(f"Error: {e}")
