@@ -1,5 +1,4 @@
 import subprocess
-import shutil
 import os
 import click
 import pathlib
@@ -8,17 +7,6 @@ from contextlib import closing
 from pangeamt_nlp.tokenizer.tokenizer_factory import TokenizerFactory
 from pangeamt_tea.project.workflow.stage.base_stage import BaseStage
 from pangeamt_tea.project.workflow.stage.stage_factory import StageFactory
-from pangeamt_nlp.multilingual_resource.tmx.tmx_reader_bilingual import (
-    TmxReaderBilingualText,
-)
-from pangeamt_nlp.multilingual_resource.af.af_reader import AfReader
-from pangeamt_nlp.multilingual_resource.bilingual.bilingual_reader import (
-    BilingualReader,
-)
-from pangeamt_nlp.multilingual_resource.dataset.dataset_reader import (
-    DatasetReader,
-)
-from pangeamt_nlp.multilingual_resource.dataset.dataset import Dataset
 from pangeamt_nlp.truecaser.truecaser import Truecaser
 from pangeamt_nlp.bpe.bpe import BPE
 from pangeamt_nlp.data_batcher.batcher import batch
@@ -42,7 +30,7 @@ class PrepareStage(BaseStage):
         self.stage_dir = os.path.join(workflow_dir, PrepareStage.DIR)
 
         if os.path.isdir(self.stage_dir):
-            raise WorkflowAlreadyExists(project_dir)
+            raise Exception("Workflow already exists: " + str(project_dir))
 
         os.mkdir(self.stage_dir)
 
@@ -52,14 +40,10 @@ class PrepareStage(BaseStage):
         await self.bpe(max_workers)
         await self.prep_batch()
 
-        # Create the file handlers for every dataset
-        def get_dir(project_dir):
-            return os.path.join(project_dir, Workflow.DIR)
-
         return {}
 
-    # Read the clean data and join both langs in a file to shuffle it without losing
-    # the alignment
+    # Read the clean data and join both langs in a file to shuffle it without
+    # losing the alignment
     async def shuffle(self):
         project = self.workflow.project
         project_dir = project.config.project_dir
@@ -90,11 +74,11 @@ class PrepareStage(BaseStage):
 
         # Shuffle the data
         print("Shufling and splitting data...")
-        subprocess.run(
+        command = (
             f'cat {all_lines_path} | sed -e "s/\r//g" | sed "s/\t//g" '
-            f"| sort | uniq | shuf  > {all_lines_shuf}",
-            shell=True,
+            f"| sort | uniq | shuf > {all_lines_shuf}"
         )
+        subprocess.run(command, shell=True)
 
         train_src = open(
             os.path.join(dir, "train_src.txt"), "w+", encoding="utf-8"
@@ -166,8 +150,8 @@ class PrepareStage(BaseStage):
         src_tok_name = project.config.tokenizer["src"]
         tgt_tok_name = project.config.tokenizer["tgt"]
 
-        # Initialize the tokenizer for each language and pair it with the files with
-        # a tuple
+        # Initialize the tokenizer for each language and pair it with the files
+        # with a tuple
         files = (
             (
                 [
@@ -224,8 +208,8 @@ class PrepareStage(BaseStage):
 
         print("Finished training")
 
-        # Initialize the truecaser for the different languages if the truecaser is
-        # enabled, if not, let it None
+        # Initialize the truecaser for the different languages if the truecaser
+        # is enabled, if not, let it None
         files = (
             (
                 [
@@ -329,8 +313,8 @@ class PrepareStage(BaseStage):
 
         print("Finished training bpe model")
 
-        # If joint, train the bpe with all the corpus, else, train with the corpus split
-        # by language
+        # If joint, train the bpe with all the corpus, else, train with the
+        # corpus split by language
         if joint:
             src_bpe = BPE(
                 os.path.join(model_dir, "codes32k.txt"),
